.. ref_VideoClip:

***********************
 Classes of Video Clips
***********************



:class:`VideoClip`
==========================

.. autoclass:: moviepy.video.VideoClip.VideoClip
   :members:
   :inherited-members:
   :show-inheritance:
   


:class:`VideoFileClip`
------------------------

.. autoclass:: moviepy.video.io.VideoFileClip.VideoFileClip
   :members:
   :inherited-members:
   :show-inheritance:


   
:class:`ImageClip`
----------------------

.. autoclass:: moviepy.video.VideoClip.ImageClip
   :members:
   :inherited-members:
   :show-inheritance:


   
:class:`ColorClip`
------------------

.. autoclass::  moviepy.video.VideoClip.ColorClip
   :members:
   :inherited-members:
   :show-inheritance:
   
   
:class:`TextClip`
---------------------

.. autoclass::  moviepy.video.VideoClip.TextClip
   :members:
   :inherited-members:
   :show-inheritance:



:class:`CompositeVideoClip`
-------------------------------

.. autoclass::  moviepy.video.compositing.CompositeVideoClip.CompositeVideoClip
   :members:
   :inherited-members:
   :show-inheritance:

